# coffeegrindsize

***[An app to measure your coffee grind size distribution](https://coffeeadastra.com/2019/04/07/an-app-to-measure-your-coffee-grind-size-distribution-2/)***

## Install

From within this directory:

```shell
pip install --user coffeegrindsize
```

## Run

```shell
coffeegrindsize
```

## Development

This is a fork of [jgagneastro/coffeegrindsize](https://github.com/jgagneastro/coffeegrindsize) intended to be cross-platform.
